value_commitment

Function value_commitment 

pub fn value_commitment(raw_value: &[u8]) -> ([u8; 32], u32)
Compute the (value_hash, value_len) commitment for a raw feed value.

This is the single place signing nodes and verifiers derive the commitment that is hashed into the EVM-compatible message. The wire DataUpdate does not store these fields.

Panics

If raw_value is longer than u32::MAX bytes.