Module payload

Module payload 

Plain DataUpdate payload struct.

Field order and types match the on-chain SubmitDataUpdateArgs instruction argument so a mechanical field copy converts between the two. With the borsh feature enabled the byte layout also matches the 161-byte anchor borsh layout, but the crate does not rely on that.

Structs

DataUpdate
A signed Molpha data update.