pub struct RegistryView {
pub current_version: u32,
pub previous_version: u32,
pub previous_expires_at: i64,
pub current_node_count: u32,
pub previous_node_count: u32,
pub last_transition_type: RegistryTransitionType,
pub removed_old_index: u32,
pub moved_old_index: u32,
}Expand description
Plain view of the registry fields needed to resolve and order signers.
The caller builds this from its own registry account (whatever framework it uses).
Fields
current_version: u32previous_version: u32previous_expires_at: i64current_node_count: u32previous_node_count: u32last_transition_type: RegistryTransitionTyperemoved_old_index: u32moved_old_index: u32Implementations
Sourceimpl RegistryView
impl RegistryView
Sourcepub fn is_remove_transition(&self) -> bool
pub fn is_remove_transition(&self) -> bool
Whether the last transition removed a node (tail removal or swap removal).