Module error

Module error 

Error type for attestation verification.

These are pure verification errors, mapped by downstream programs at the call boundary. Account-borrow/deserialization errors are produced and handled by the caller (which owns the framework-specific account I/O) and never cross the crate boundary.

Enable the thiserror feature for std::error::Error and std::fmt::Display when using this crate in off-chain tooling.

Enums

AttestationError